function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import PropTypes from 'prop-types';
import { isDarkMode } from '@cloudflare/style-const';
import { createStyledComponent } from '@cloudflare/style-container';
import { transparentize } from 'polished';

const hueColors = hue => {
  switch (hue) {
    case 'red':
      return isDarkMode() ? {
        backgroundColor: 'red.3',
        color: 'gray.9'
      } : {
        backgroundColor: 'red.8',
        color: 'red.1'
      };

    case 'blue':
      return isDarkMode() ? {
        backgroundColor: 'blue.3',
        color: 'blue.9'
      } : {
        backgroundColor: 'blue.8',
        color: 'blue.1'
      };

    case 'green':
      return isDarkMode() ? {
        backgroundColor: 'green.3',
        color: 'gray.9'
      } : {
        backgroundColor: 'green.8',
        color: 'green.0'
      };

    case 'orange':
      return isDarkMode() ? {
        backgroundColor: 'orange.2',
        color: 'gray.9'
      } : {
        backgroundColor: 'orange.8',
        color: 'orange.1'
      };

    default:
      return isDarkMode() ? {
        backgroundColor: 'gray.2',
        color: 'gray.9'
      } : {
        backgroundColor: 'gray.8',
        color: 'gray.1'
      };
  }
};

const toHexString = (themeColor, theme) => {
  const _themeColor$split = themeColor.split('.'),
        _themeColor$split2 = _slicedToArray(_themeColor$split, 2),
        color = _themeColor$split2[0],
        scale = _themeColor$split2[1];

  return theme.colors[color][scale];
};

const styles = ({
  theme,
  hue = 'gray',
  pulse = false
}) => {
  const _hueColors = hueColors(hue),
        color = _hueColors.color,
        backgroundColor = _hueColors.backgroundColor;

  return _objectSpread({
    alignItems: 'center',
    borderRadius: '50px',
    color,
    display: 'inline-flex',
    fontSize: 1,
    fontWeight: 400,
    lineHeight: theme.lineHeights.solid,
    userSelect: 'none',
    whiteSpace: 'nowrap',
    px: 2,
    py: 1,
    backgroundColor
  }, pulse && {
    animationName: {
      '0%': {
        boxShadow: `0 0 0 0 ${transparentize(0.4, toHexString(backgroundColor, theme))}`
      },
      '70%': {
        boxShadow: `0 0 0 10px ${transparentize(1, toHexString(backgroundColor, theme))}`
      },
      '100%': {
        boxShadow: `0 0 0 0 ${transparentize(1, toHexString(backgroundColor, theme))}`
      }
    },
    animationDuration: '2s',
    animationIterationCount: 'infinite'
  });
};

const Label = createStyledComponent(styles, 'span');
Label.propTypes = {
  hue: PropTypes.oneOf(['green', 'orange', 'red', 'gray', 'blue']).isRequired
};
export default Label;